@@ -36,7 +36,7 @@
  */
 #ifndef AUTOGEN_BUILD
 #define AUTOGEN_BUILD 1
-
+#include <stdnoreturn.h>
 #include "compat/unlocked-io.h"
 
 #include REGEX_HEADER
@@ -69,6 +69,7 @@
 #include "autoopts/autoopts.h"
 #include "directive.h"
 #include "snprintfv/printf.h"
+#include "scribble.h"
 
 #define  LOG10_2to32  10  /* rounded up */
 
