@@ -327,6 +327,8 @@ print_indentation(templ_t * tpl, macro_t * mac, int idx)
     else fprintf(trace_fp, "%3u ", (unsigned int)idx);
     snprintf(fmt, sizeof(fmt), fmt_fmt, tpl_nest_lvl);
     fprintf(trace_fp, fmt, "");
+    (void)tpl;
+    (void)mac;
 }
 
  static void
