@@ -1,12 +1,16 @@
 
 /**
- * \file xml2ag.c
+ *  @file xml2ag.c
  *
  *  This is the main routine for xml2ag.
- *  xml2ag Copyright (c) 2002-2012 by Bruce Korb - all rights reserved
  *
+ *  @group xml2ag
+ *  @{
+ */
+/*
+ *  xml2ag Copyright (C) 2002-2013 by Bruce Korb - all rights reserved
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -223,7 +227,7 @@ trim( char const* pzSrc, size_t* pSz )
             if (pSz != NULL) *pSz = 0;
             return zNil;
         }
-        strSize = (pzEnd - pzSrc);
+        strSize = (size_t)(pzEnd - pzSrc);
     }
 
     /*
